@@ -37,6 +37,7 @@
  * Exception class for almost all Python errors
  */
 extern PyObject *PyAptError;
+extern PyObject *PyAptWarning;
 /**
  * Exception class for invalidated cache objects.
  */
@@ -186,6 +187,8 @@ void CppDealloc(PyObject *iObj)
    #ifdef ALLOC_DEBUG
    std::cerr << "=== DEALLOCATING " << iObj->ob_type->tp_name << "+ ===\n";
    #endif
+   if (iObj->ob_type->tp_flags & Py_TPFLAGS_HAVE_GC)
+       PyObject_GC_UnTrack(iObj);
    CppPyObject<T> *Obj = (CppPyObject<T> *)iObj;
    if (!((CppPyObject<T>*)Obj)->NoDelete)
       Obj->Object.~T();
@@ -200,6 +203,8 @@ void CppDeallocPtr(PyObject *iObj)
    #ifdef ALLOC_DEBUG
    std::cerr << "=== DEALLOCATING " << iObj->ob_type->tp_name << "*+ ===\n";
    #endif
+   if (iObj->ob_type->tp_flags & Py_TPFLAGS_HAVE_GC)
+       PyObject_GC_UnTrack(iObj);
    CppPyObject<T> *Obj = (CppPyObject<T> *)iObj;
    if (!((CppPyObject<T>*)Obj)->NoDelete)  {
       delete Obj->Object;
